#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_TOUINT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_TOUINT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/touint.hpp>

#endif
